@@ -6,7 +6,7 @@ import requests
 from urllib3.exceptions import InsecureRequestWarning
 from xmlApiParse.enums import SpecificCollectionsEnum, AllCollectionsEnum
 from xmlApiParse.repository import (
-    OrderLineDTO, ParseError, ConnectionErrors, BadRequestError,
+    OrderLineDTO, ParseError, ConnectionErrors, BadRequestError, SystemInfoDTO,
     WaiterListDTO, OrderListDTO, RestaurantsDTO,
     MenuDTO, MenuItemsDTO, EmployeeDTO, WaiterDTO,
     GetVisitDTO
@@ -127,6 +127,33 @@ class RKXMLRequest(XMLRequest):
                 "child":  self._xml_convert(elements=child)}
         return data
 
+    def get_system_info_request(self):
+        """request to get all collections"""
+
+        body = f'<RK7Query><RK7CMD CMD="GetSystemInfo2"/></RK7Query>'
+        response = self.send_request(body=body)
+        try:
+            parsed_element = Etree.fromstring(response.content)
+            system_info_response = parsed_element.find("./SystemInfo")
+
+            if system_info_response is None:
+                return None
+
+            restaurant_response = system_info_response.find('Restaurant')
+            restaurant = RestaurantsDTO(name=restaurant_response.attrib['name'],
+                                        alt_name='',
+                                        ident=restaurant_response.attrib['id'])
+
+            restaurant_code_response = system_info_response.attrib['RestCode']
+
+            system_info = SystemInfoDTO(
+                restaurant=restaurant, restaurant_code=restaurant_code_response)
+
+            return system_info
+
+        except Exception as error:
+            raise ParseError(f"XML parse error - {str(error)}")
+
     def all_collections_request(self, collection: AllCollectionsEnum):
         """request to get all collections"""
 
@@ -213,7 +240,7 @@ class RKXMLRequest(XMLRequest):
         return elements
 
     def order_list_request(self, last_version: int | None = None,
-                        only_opened: bool = False) -> tuple[List[OrderListDTO], int | None]:
+                           only_opened: bool = False) -> tuple[List[OrderListDTO], int | None]:
         """requests to receive the entire order"""
 
         last_version_represent = f'lastversion="{last_version}"' if last_version else ''
@@ -234,15 +261,18 @@ class RKXMLRequest(XMLRequest):
                                              version=order.get('Version'), crc32=order.get('Crc32'),
                                              guid=order.get('guid'), table_id=(order.get('TableID')),
                                              table_code=order.get('TableCode'),
-                                             order_categ_id=order.get('OrderCategId'),
+                                             order_categ_id=order.get(
+                                                 'OrderCategId'),
                                              order_categ_code=order.get('OrderCategCode'), bill=order.get('Bill'),
                                              waiter_id=order.get('WaiterID'),
-                                             order_type_code=order.get('OrderTypeCode'),
+                                             order_type_code=order.get(
+                                                 'OrderTypeCode'),
                                              order_type_id=order.get('OrderTypeID'), to_pay_sum=order.get('ToPaySum'),
                                              waiter_code=order.get('WaiterCode'), order_sum=order.get('OrderSum'),
                                              total_pieces=order.get('TotalPieces'), finished=order.get('Finished'),
                                              price_list_sum=order.get('PriceListSum'), dessert=order.get('Dessert'),
-                                             created_time=order.get('CreateTime'),
+                                             created_time=order.get(
+                                                 'CreateTime'),
                                              finished_time=order.get('FinishTime'))
                     element_list.append(order_dto)
             last_version_str = parsed_element.find('CommandResult').attrib.get(
