@@ -140,6 +140,12 @@ class GetVisitDTO():
     guid: str
 
 
+@dataclass
+class SystemInfoDTO():
+    restaurant: RestaurantsDTO
+    restaurant_code: str
+
+
 class ConnectionErrors(Exception):
     pass
 
